package xhttp3.internal.platform;

import android.annotation.SuppressLint;
import android.util.Log;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.List;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import xhttp3.Protocol;
import xhttp3.internal.Util;
import xhttp3.internal.tls.CertificateChainCleaner;

class AndroidPlatform extends Platform {
   private static final int MAX_LOG_LENGTH = 4000;
   private final Class<?> sslParametersClass;
   private final OptionalMethod<Socket> setUseSessionTickets;
   private final OptionalMethod<Socket> setHostname;
   private final OptionalMethod<Socket> getAlpnSelectedProtocol;
   private final OptionalMethod<Socket> setAlpnProtocols;

   public AndroidPlatform(Class<?> sslParametersClass, OptionalMethod<Socket> setUseSessionTickets, OptionalMethod<Socket> setHostname, OptionalMethod<Socket> getAlpnSelectedProtocol, OptionalMethod<Socket> setAlpnProtocols) {
      this.sslParametersClass = sslParametersClass;
      this.setUseSessionTickets = setUseSessionTickets;
      this.setHostname = setHostname;
      this.getAlpnSelectedProtocol = getAlpnSelectedProtocol;
      this.setAlpnProtocols = setAlpnProtocols;
   }

   @SuppressLint({"PrivateApi"})
   public static Platform buildIfSupported() {
      Class var10000;
      boolean var10001;
      try {
         var10000 = Class.forName("com.android.org.conscript.SSLParametersImpl");
      } catch (ClassNotFoundException var20) {
         try {
            var10000 = Class.forName("org.apache.harmony.xnet.provider.jsse.SSLParametersImpl");
         } catch (ClassNotFoundException var19) {
            var10001 = false;
            return null;
         }
      }

      Class var0 = var10000;

      OptionalMethod var21;
      try {
         var21 = new OptionalMethod;
      } catch (ClassNotFoundException var18) {
         var10001 = false;
         return null;
      }

      OptionalMethod var1 = var21;
      Class var22 = null;
      String var10002 = "setUseSessionTickets";

      Class[] var10003;
      try {
         var10003 = new Class[1];
      } catch (ClassNotFoundException var17) {
         var10001 = false;
         return null;
      }

      Class[] var10004 = var10003;
      byte var10005 = 0;

      try {
         var10004[var10005] = Boolean.TYPE;
         var21.<init>(var22, var10002, var10003);
         var21 = new OptionalMethod;
      } catch (ClassNotFoundException var16) {
         var10001 = false;
         return null;
      }

      OptionalMethod var2 = var21;
      var22 = null;
      var10002 = "setHostname";

      try {
         var10003 = new Class[1];
      } catch (ClassNotFoundException var15) {
         var10001 = false;
         return null;
      }

      var10004 = var10003;
      var10005 = 0;

      try {
         var10004[var10005] = String.class;
         var21.<init>(var22, var10002, var10003);
      } catch (ClassNotFoundException var14) {
         var10001 = false;
         return null;
      }

      OptionalMethod var3 = null;
      Object var4 = null;

      OptionalMethod var5;
      label96: {
         label131: {
            label94: {
               label129: {
                  try {
                     Class.forName("android.net.Network");
                  } catch (ClassNotFoundException var12) {
                     var10001 = false;
                     break label129;
                  }

                  try {
                     var21 = new OptionalMethod;
                  } catch (ClassNotFoundException var11) {
                     var10001 = false;
                     break label129;
                  }

                  var5 = var21;

                  try {
                     var22 = byte[].class;
                  } catch (ClassNotFoundException var10) {
                     var10001 = false;
                     break label129;
                  }

                  var10002 = "getAlpnSelectedProtocol";

                  try {
                     var21.<init>(var22, var10002);
                     break label94;
                  } catch (ClassNotFoundException var9) {
                     var10001 = false;
                  }
               }

               var5 = var3;
               break label131;
            }

            try {
               var21 = new OptionalMethod;
            } catch (ClassNotFoundException var8) {
               var10001 = false;
               break label131;
            }

            var3 = var21;
            var22 = null;
            var10002 = "setAlpnProtocols";

            try {
               var10003 = new Class[1];
            } catch (ClassNotFoundException var7) {
               var10001 = false;
               break label131;
            }

            var10004 = var10003;
            var10005 = 0;

            try {
               var10004[var10005] = byte[].class;
               var21.<init>(var22, var10002, var10003);
               break label96;
            } catch (ClassNotFoundException var6) {
               var10001 = false;
            }
         }

         var3 = (OptionalMethod)var4;
      }

      try {
         return new AndroidPlatform(var0, var1, var2, var5, var3);
      } catch (ClassNotFoundException var13) {
         var10001 = false;
         return null;
      }
   }

   public void connectSocket(Socket socket, InetSocketAddress address, int connectTimeout) {
      try {
         socket.connect(address, connectTimeout);
      } catch (AssertionError var4) {
         if (Util.isAndroidGetsocknameError(var4)) {
            throw new IOException(var4);
         } else {
            throw var4;
         }
      } catch (SecurityException var5) {
         IOException var10000 = new IOException("Exception in connect");
         var10000.initCause(var5);
         throw var10000;
      }
   }

   public X509TrustManager trustManager(SSLSocketFactory sslSocketFactory) {
      Object var2;
      if ((var2 = Platform.readFieldOrNull(sslSocketFactory, this.sslParametersClass, "sslParameters")) == null) {
         SSLSocketFactory var10000 = sslSocketFactory;
         String var10001 = "com.google.android.gms.org.conscrypt.SSLParametersImpl";
         boolean var10002 = false;

         Object var5;
         try {
            var5 = Platform.readFieldOrNull(var10000, Class.forName(var10001, var10002, sslSocketFactory.getClass().getClassLoader()), "sslParameters");
         } catch (ClassNotFoundException var3) {
            return super.trustManager(sslSocketFactory);
         }

         var2 = var5;
      }

      X509TrustManager var4;
      return (var4 = (X509TrustManager)Platform.readFieldOrNull(var2, X509TrustManager.class, "x509TrustManager")) != null ? var4 : (X509TrustManager)Platform.readFieldOrNull(var2, X509TrustManager.class, "trustManager");
   }

   public void configureTlsExtensions(SSLSocket sslSocket, String hostname, List<Protocol> protocols) {
      if (hostname != null) {
         OptionalMethod var10001 = this.setUseSessionTickets;
         Object[] var4;
         (var4 = new Object[1])[0] = Boolean.TRUE;
         var10001.invokeOptionalWithoutCheckedException(sslSocket, var4);
         OptionalMethod var10000 = this.setHostname;
         (var4 = new Object[1])[0] = hostname;
         var10000.invokeOptionalWithoutCheckedException(sslSocket, var4);
      }

      OptionalMethod hostname1;
      if ((hostname1 = this.setAlpnProtocols) != null && hostname1.isSupported(sslSocket)) {
         AndroidPlatform var7 = this;
         Object[] var5;
         (var5 = new Object[1])[0] = Platform.concatLengthPrefixed(protocols);
         var7.setAlpnProtocols.invokeWithoutCheckedException(sslSocket, var5);
      }

   }

   public String getSelectedProtocol(SSLSocket socket) {
      OptionalMethod var2;
      if ((var2 = this.getAlpnSelectedProtocol) == null) {
         return null;
      } else if (!var2.isSupported(socket)) {
         return null;
      } else {
         byte[] var3;
         String socket1;
         if ((var3 = (byte[])this.getAlpnSelectedProtocol.invokeWithoutCheckedException(socket)) != null) {
            socket1 = new String.<init>(var3, Util.UTF_8);
         } else {
            socket1 = null;
         }

         return socket1;
      }
   }

   public void log(int level, String message, Throwable t) {
      byte var6;
      if (level == 5) {
         var6 = 5;
      } else {
         var6 = 3;
      }

      if (t != null) {
         message = message + '\n' + Log.getStackTraceString(t);
      }

      level = 0;

      int var5;
      for(int t1 = message.length(); level < t1; level = var5 + 1) {
         int var4;
         if ((var4 = message.indexOf(10, level)) == -1) {
            var4 = t1;
         }

         while(true) {
            int var10000 = var5 = Math.min(var4, level + 4000);
            Log.println(var6, "OkHttp", message.substring(level, var5));
            if (var10000 >= var4) {
               break;
            }

            level = var5;
         }
      }

   }

   public boolean isCleartextTrafficPermitted(String hostname) {
      Class var10000;
      boolean var10001;
      try {
         var10000 = Class.forName("android.security.NetworkSecurityPolicy");
      } catch (ClassNotFoundException var23) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (NoSuchMethodException var24) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (IllegalAccessException var25) {
         var10001 = false;
         throw new AssertionError();
      } catch (IllegalArgumentException var26) {
         var10001 = false;
         throw new AssertionError();
      } catch (InvocationTargetException var27) {
         var10001 = false;
         throw new AssertionError();
      }

      Class var28 = var10000;
      String var10002 = "getInstance";

      Method var30;
      try {
         var30 = var28.getMethod(var10002);
      } catch (ClassNotFoundException var18) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (NoSuchMethodException var19) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (IllegalAccessException var20) {
         var10001 = false;
         throw new AssertionError();
      } catch (IllegalArgumentException var21) {
         var10001 = false;
         throw new AssertionError();
      } catch (InvocationTargetException var22) {
         var10001 = false;
         throw new AssertionError();
      }

      var10002 = null;

      Object var31;
      try {
         var31 = var30.invoke(var10002);
      } catch (ClassNotFoundException var13) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (NoSuchMethodException var14) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (IllegalAccessException var15) {
         var10001 = false;
         throw new AssertionError();
      } catch (IllegalArgumentException var16) {
         var10001 = false;
         throw new AssertionError();
      } catch (InvocationTargetException var17) {
         var10001 = false;
         throw new AssertionError();
      }

      Object var2 = var31;
      String var32 = "isCleartextTrafficPermitted";

      Class[] var29;
      try {
         var29 = new Class[1];
      } catch (ClassNotFoundException var8) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (NoSuchMethodException var9) {
         var10001 = false;
         return super.isCleartextTrafficPermitted(hostname);
      } catch (IllegalAccessException var10) {
         var10001 = false;
         throw new AssertionError();
      } catch (IllegalArgumentException var11) {
         var10001 = false;
         throw new AssertionError();
      } catch (InvocationTargetException var12) {
         var10001 = false;
         throw new AssertionError();
      }

      Class[] var10003 = var29;
      byte var10004 = 0;

      try {
         var10003[var10004] = String.class;
         return (Boolean)var10000.getMethod(var32, var29).invoke(var2, hostname);
      } catch (ClassNotFoundException var3) {
         var10001 = false;
      } catch (NoSuchMethodException var4) {
         var10001 = false;
      } catch (IllegalAccessException var5) {
         var10001 = false;
         throw new AssertionError();
      } catch (IllegalArgumentException var6) {
         var10001 = false;
         throw new AssertionError();
      } catch (InvocationTargetException var7) {
         var10001 = false;
         throw new AssertionError();
      }

      return super.isCleartextTrafficPermitted(hostname);
   }

   public CertificateChainCleaner buildCertificateChainCleaner(X509TrustManager trustManager) {
      Class var13;
      Class var10000;
      boolean var10001;
      Class[] var10002;
      try {
         var10000 = Class.forName("android.net.http.X509TrustManagerExtensions");
         var13 = var10000;
         var10002 = new Class[1];
      } catch (Exception var10) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }

      Class[] var10003 = var10002;
      byte var10004 = 0;

      Object var14;
      try {
         var10003[var10004] = X509TrustManager.class;
         var14 = var13.getConstructor(var10002).newInstance(trustManager);
      } catch (Exception var9) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }

      Object var2 = var14;
      String var15 = "checkServerTrusted";

      try {
         var10002 = new Class[3];
      } catch (Exception var8) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }

      var10003 = var10002;
      Class[] var16 = var10002;
      Class[] var10005 = var10002;
      byte var10006 = 0;

      try {
         var10005[var10006] = X509Certificate[].class;
      } catch (Exception var7) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }

      byte var11 = 1;

      try {
         var16[var11] = String.class;
      } catch (Exception var6) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }

      var10004 = 2;

      Method var12;
      try {
         var10003[var10004] = String.class;
         var12 = var10000.getMethod(var15, var10002);
      } catch (Exception var5) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }

      Method var3 = var12;

      try {
         return new AndroidCertificateChainCleaner(var2, var3);
      } catch (Exception var4) {
         var10001 = false;
         return super.buildCertificateChainCleaner(trustManager);
      }
   }

   static final class AndroidCertificateChainCleaner extends CertificateChainCleaner {
      private final Object x509TrustManagerExtensions;
      private final Method checkServerTrusted;

      AndroidCertificateChainCleaner(Object x509TrustManagerExtensions, Method checkServerTrusted) {
         this.x509TrustManagerExtensions = x509TrustManagerExtensions;
         this.checkServerTrusted = checkServerTrusted;
      }

      public List<Certificate> clean(List<Certificate> param1, String param2) {
         // $FF: Couldn't be decompiled
      }
   }
}
